# frozen_string_literal: true

require_rel 'image_magick'

# TODO: Refactor out ImageMagick code
module ImageDiff
  module Differ
    # ImageDiff class
    class ImageDiff < Diff
      def result
        index, debug = ImageMagick.absolute_error(args)
        send(%i[pass fail][index] || :error, debug)
      end

      private

      def comparison
        File.join(snapshot.fullpath, snapshot.filename.gsub('.png', '_diff.png'))
      end

      def args
        [reference, snapshot.path_and_filename, comparison].join(' ')
      end

      def pass(_debug)
        File.delete(comparison, snapshot.path_and_filename)
      end

      def fail(debug)
        Results::PixelRegression.new(reference, snapshot, debug, comparison)
      end

      def error(debug)
        if debug[/unable to open image/]
          Results::ReferenceFileNotFound.new(snapshot)
        else
          # TODO: This is a failure so should add Result to Results list
          print %(\033[31m#{debug}\033[0m)
        end
      end
    end
  end
end
