# frozen_string_literal: true

require_rel 'result'

module ImageDiff
  module Differ
    module Results
      # Results list
      class List
        extend Forwardable
        include Singleton

        def_delegators :@list, :ai, :[], :each_with_object, :empty?

        def initialize
          clear
        end

        def clear
          @list = Hash.new { |hash, key| hash[key] = [] }
        end

        def filter(method)
          each_with_object({}) do |(component, results), hash|
            selected = Filter.apply(results, method)
            hash[component] = selected unless selected.empty?
          end
        end

        def reference_errors
          filter(:select)
        end

        def regressions
          filter(:reject)
        end
      end

      # Helper class to filter array
      class Filter
        KLASS = ImageDiff::Differ::Results::ReferenceFileNotFound
        LAMBDA = ->(result) { result.is_a?(KLASS) }

        def self.apply(arr, method)
          arr.send(method, &LAMBDA)
        end
      end
    end
  end
end
