# frozen_string_literal: true
require 'erb'

module ImageDiff
  module Differ
    module Results
      # Decorator for Results hash
      class Output < SimpleDelegator
        CURRENT_DIR = File.dirname(__FILE__)

        def initialize
          super(List.instance)
          @regressions = regressions
          @reference_errors = reference_errors
        end

        def out
          render_reference_errors
          render_regression_errors
        end

        def render_reference_errors
          print_str = String.new ''
          unless @reference_errors.empty?
            @reference_errors.map do |component, failures|
              print_str << "The following reference files were not found, you need to generate screenshots before comparing...\n"
              failures.each do |failure|
                print_str << "\033[31m#{failure.snapshot.filename}\033[0m\n"
              end
            end
          end
          print print_str
        end

        def render_regression_errors
          print_str = String.new ''
          unless @regressions.empty?
            @regressions.map do |component, failures|
              print_str << "The following screenshots are different from the comparison image, if this expected then regenerate comparison images...\n"
              failures.each do |failure|
                print_str << "\033[31m#{failure.output}\033[0m\n"
              end
            end
          end
          print print_str
        end

        def self.clear
          List.instance.clear
        end

        def self.flush
          return if List.instance.empty?

          new.out
        end
      end
    end
  end
end
