# frozen_string_literal: true

module ImageDiff
  module Differ
    module Results
      # Comparison result
      class Result
        attr_reader :snapshot

        def initialize(snapshot)
          @snapshot = snapshot
          add_to_results_list
        end

        def add_to_results_list
          List.instance[@snapshot.filepath] << self
        end
      end

      # Reference File Not Found
      class ReferenceFileNotFound < Result
      end

      # Pixel Regression
      class PixelRegression < Result
        def initialize(reference, snapshot, error, comparison)
          @error = error
          @comparison = comparison
          @reference = reference
          super(snapshot)
        end

        def output
          <<~BODY
            ----------------------
            Reference file: #{@reference}
            Screenshot:  #{snapshot.filepath}.png
            Difference: #{@comparison}
            ----------------------
          BODY
        end
      end
    end
  end
end
